@@ -4,18 +4,18 @@
 # -- SOAP::Lite -- soaplite.com -- Copyright (C) 2001 Paul Kulchenko --
 
 use SOAP::Lite +autodispatch => 
-  uri => 'http://my.own.site.com/My/Parameters',
+  uri => 'http://www.soaplite.com/My/Chat',
   proxy => 'http://localhost/soap',
 # proxy => 'http://localhost/',                 # local daemon server
 # proxy => 'http://localhost/soap',             # local mod_perl server
 # proxy => 'https://localhost/soap',            # local mod_perl SECURE server
 # proxy => 'tcp:localhost:82',                  # local tcp server
   on_fault => sub { my($soap, $res) = @_; 
-    die ref $res ? $res->faultdetail : $soap->transport->status, "\n";
+    die ref $res ? $res->faultstring : $soap->transport->status, "\n";
   }
 ;
 
-my $nick = shift;
+my $nick = shift or die "Usage: $0 nickname\n";
 my $c = My::Chat->join($nick);
 my %whois = %{$c->whois};
 print map { "$_ [" . mktime($whois{$_}) . "]\n" } keys %whois;
